// 
// Copyright (c) Microsoft and contributors.  All rights reserved.
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//   http://www.apache.org/licenses/LICENSE-2.0
// 
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// 
// See the License for the specific language governing permissions and
// limitations under the License.
// 

// Warning: This code was generated by a tool.
// 
// Changes to this file may cause incorrect behavior and will be lost if the
// code is regenerated.

using System;
using System.Linq;
using System.Threading;
using System.Threading.Tasks;
using Microsoft.WindowsAzure.Management.Sql;
using Microsoft.WindowsAzure.Management.Sql.Models;

namespace Microsoft.WindowsAzure.Management.Sql
{
    /// <summary>
    /// This is the main client class for interacting with the Azure SQL
    /// Database REST APIs.
    /// </summary>
    public static partial class QuotaOperationsExtensions
    {
        /// <summary>
        /// Retrieves the specified quota from the server.
        /// </summary>
        /// <param name='operations'>
        /// Reference to the
        /// Microsoft.WindowsAzure.Management.Sql.IQuotaOperations.
        /// </param>
        /// <param name='serverName'>
        /// Required. The name of the Azure SQL Database Server from which to
        /// retrieve the quota.
        /// </param>
        /// <param name='quotaName'>
        /// Required. The name of the quota to retrieve.
        /// </param>
        /// <returns>
        /// Represents the response structure for the Quota Get operation.
        /// </returns>
        public static QuotaGetResponse Get(this IQuotaOperations operations, string serverName, string quotaName)
        {
            return Task.Factory.StartNew((object s) => 
            {
                return ((IQuotaOperations)s).GetAsync(serverName, quotaName);
            }
            , operations, CancellationToken.None, TaskCreationOptions.None, TaskScheduler.Default).Unwrap().GetAwaiter().GetResult();
        }
        
        /// <summary>
        /// Retrieves the specified quota from the server.
        /// </summary>
        /// <param name='operations'>
        /// Reference to the
        /// Microsoft.WindowsAzure.Management.Sql.IQuotaOperations.
        /// </param>
        /// <param name='serverName'>
        /// Required. The name of the Azure SQL Database Server from which to
        /// retrieve the quota.
        /// </param>
        /// <param name='quotaName'>
        /// Required. The name of the quota to retrieve.
        /// </param>
        /// <returns>
        /// Represents the response structure for the Quota Get operation.
        /// </returns>
        public static Task<QuotaGetResponse> GetAsync(this IQuotaOperations operations, string serverName, string quotaName)
        {
            return operations.GetAsync(serverName, quotaName, CancellationToken.None);
        }
        
        /// <summary>
        /// Returns a list of quotas from the server.
        /// </summary>
        /// <param name='operations'>
        /// Reference to the
        /// Microsoft.WindowsAzure.Management.Sql.IQuotaOperations.
        /// </param>
        /// <param name='serverName'>
        /// Required. The name of the Azure SQL Database Server from which to
        /// get the quotas.
        /// </param>
        /// <returns>
        /// Represents the response structure for the Quota List operation.
        /// </returns>
        public static QuotaListResponse List(this IQuotaOperations operations, string serverName)
        {
            return Task.Factory.StartNew((object s) => 
            {
                return ((IQuotaOperations)s).ListAsync(serverName);
            }
            , operations, CancellationToken.None, TaskCreationOptions.None, TaskScheduler.Default).Unwrap().GetAwaiter().GetResult();
        }
        
        /// <summary>
        /// Returns a list of quotas from the server.
        /// </summary>
        /// <param name='operations'>
        /// Reference to the
        /// Microsoft.WindowsAzure.Management.Sql.IQuotaOperations.
        /// </param>
        /// <param name='serverName'>
        /// Required. The name of the Azure SQL Database Server from which to
        /// get the quotas.
        /// </param>
        /// <returns>
        /// Represents the response structure for the Quota List operation.
        /// </returns>
        public static Task<QuotaListResponse> ListAsync(this IQuotaOperations operations, string serverName)
        {
            return operations.ListAsync(serverName, CancellationToken.None);
        }
    }
}
